24 lines
6.3 KiB
HTML
24 lines
6.3 KiB
HTML
|
|
<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="Used to control how child nodes are aligned. Does not apply to Flexbox, and will be ignored if specified on a flex container For Grid it controls alignment in the inline axis"><title>JustifyItems in cosmic::widget - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../../static.files/${f}">`).join(""))</script><link rel="stylesheet" href="../../static.files/normalize-9960930a.css"><link rel="stylesheet" href="../../static.files/rustdoc-aa0817cf.css"><meta name="rustdoc-vars" data-root-path="../../" data-static-root-path="../../static.files/" data-current-crate="cosmic" data-themes="" data-resource-suffix="" data-rustdoc-version="1.90.0-nightly (3048886e5 2025-07-30)" data-channel="nightly" data-search-js="search-fa3e91e5.js" data-settings-js="settings-5514c975.js" ><script src="../../static.files/storage-68b7e25d.js"></script><script defer src="sidebar-items.js"></script><script defer src="../../static.files/main-eebb9057.js"></script><noscript><link rel="stylesheet" href="../../static.files/noscript-32bb7600.css"></noscript><link rel="alternate icon" type="image/png" href="../../static.files/favicon-32x32-6580c154.png"><link rel="icon" type="image/svg+xml" href="../../static.files/favicon-044be391.svg"></head><body class="rustdoc type"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="mobile-topbar"><button class="sidebar-menu-toggle" title="show sidebar"></button></nav><nav class="sidebar"><div class="sidebar-crate"><h2><a href="../../cosmic/index.html">cosmic</a><span class="version">1.0.0</span></h2></div><div class="sidebar-elems"><section id="rustdoc-toc"><h2 class="location"><a href="#">Justify<wbr>Items</a></h2><h3><a href="#aliased-type">Aliased Type</a></h3><h3><a href="#variants">Variants</a></h3><ul class="block variant"><li><a href="#variant.Baseline" title="Baseline">Baseline</a></li><li><a href="#variant.Center" title="Center">Center</a></li><li><a href="#variant.End" title="End">End</a></li><li><a href="#variant.FlexEnd" title="FlexEnd">FlexEnd</a></li><li><a href="#variant.FlexStart" title="FlexStart">FlexStart</a></li><li><a href="#variant.Start" title="Start">Start</a></li><li><a href="#variant.Stretch" title="Stretch">Stretch</a></li></ul></section><div id="rustdoc-modnav"><h2><a href="index.html">In cosmic::<wbr>widget</a></h2></div></div></nav><div class="sidebar-resizer" title="Drag to resize sidebar"></div><main><div class="width-limiter"><rustdoc-search></rustdoc-search><section id="main-content" class="content"><div class="main-heading"><div class="rustdoc-breadcrumbs"><a href="../index.html">cosmic</a>::<wbr><a href="index.html">widget</a></div><h1>Type Alias <span class="type">JustifyItems</span><button id="copy-path" title="Copy item path to clipboard">Copy item path</button></h1><rustdoc-toolbar></rustdoc-toolbar><span class="sub-heading"></span></div><pre class="rust item-decl"><code>pub type JustifyItems = AlignItems;</code></pre><details class="toggle top-doc" open><summary class="hideme"><span>Expand description</span></summary><div class="docblock"><p>Used to control how child nodes are aligned.
|
||
|
|
Does not apply to Flexbox, and will be ignored if specified on a flex container
|
||
|
|
For Grid it controls alignment in the inline axis</p>
|
||
|
|
<p><a href="https://developer.mozilla.org/en-US/docs/Web/CSS/justify-items">MDN</a></p>
|
||
|
|
</div></details><h2 id="aliased-type" class="section-header">Aliased Type<a href="#aliased-type" class="anchor"></a></h2><pre class="rust item-decl"><code>pub enum JustifyItems {
|
||
|
|
Start,
|
||
|
|
End,
|
||
|
|
FlexStart,
|
||
|
|
FlexEnd,
|
||
|
|
Center,
|
||
|
|
Baseline,
|
||
|
|
Stretch,
|
||
|
|
}</code></pre><h2 id="variants" class="variants section-header">Variants<a href="#variants" class="anchor"></a></h2><div class="variants"><section id="variant.Start" class="variant"><a href="#variant.Start" class="anchor"></a><h3 class="code-header">Start</h3></section><div class="docblock"><p>Items are packed toward the start of the axis</p>
|
||
|
|
</div><section id="variant.End" class="variant"><a href="#variant.End" class="anchor"></a><h3 class="code-header">End</h3></section><div class="docblock"><p>Items are packed toward the end of the axis</p>
|
||
|
|
</div><section id="variant.FlexStart" class="variant"><a href="#variant.FlexStart" class="anchor"></a><h3 class="code-header">FlexStart</h3></section><div class="docblock"><p>Items are packed towards the flex-relative start of the axis.</p>
|
||
|
|
<p>For flex containers with flex_direction RowReverse or ColumnReverse this is equivalent
|
||
|
|
to End. In all other cases it is equivalent to Start.</p>
|
||
|
|
</div><section id="variant.FlexEnd" class="variant"><a href="#variant.FlexEnd" class="anchor"></a><h3 class="code-header">FlexEnd</h3></section><div class="docblock"><p>Items are packed towards the flex-relative end of the axis.</p>
|
||
|
|
<p>For flex containers with flex_direction RowReverse or ColumnReverse this is equivalent
|
||
|
|
to Start. In all other cases it is equivalent to End.</p>
|
||
|
|
</div><section id="variant.Center" class="variant"><a href="#variant.Center" class="anchor"></a><h3 class="code-header">Center</h3></section><div class="docblock"><p>Items are packed along the center of the cross axis</p>
|
||
|
|
</div><section id="variant.Baseline" class="variant"><a href="#variant.Baseline" class="anchor"></a><h3 class="code-header">Baseline</h3></section><div class="docblock"><p>Items are aligned such as their baselines align</p>
|
||
|
|
</div><section id="variant.Stretch" class="variant"><a href="#variant.Stretch" class="anchor"></a><h3 class="code-header">Stretch</h3></section><div class="docblock"><p>Stretch to fill the container</p>
|
||
|
|
</div></div><script src="../../type.impl/taffy/style/alignment/enum.AlignItems.js" data-self-path="cosmic::widget::JustifyItems" async></script></section></div></main></body></html>
|